@@ -42,7 +42,7 @@ class Frame:
     blasurl      = 'http://netlib.org/blas/blas.tgz'
     lapackurl    = 'http://netlib.org/lapack/lapack.tgz'
     blacsurl     = 'http://netlib.org/blacs/mpiblacs.tgz'
-    scalapackurl = 'http://netlib.org/scalapack/scalapack-1.8.0.tgz'
+    scalapackurl = 'http://netlib.org/scalapack/scalapack.tgz'
     ranlib       = ''                        # the ranlib command
     clean        = 0
 
