@@ -51,7 +51,7 @@ class Lapack(Frame):
       stop
       end\n""")
 
-        fcomm = self.mpif77+' -o tmpf '+'tmpf.f '+self.lapacklib+' '+self.blaslib+' '+self.ldflags_f77
+        fcomm = self.mpif77+' '+Frame.fcflags+' -o tmpf '+'tmpf.f '+self.lapacklib+' '+self.blaslib+' '+self.ldflags_f77
         (output, error, retz) = runShellCommand(fcomm)
 
         if(retz != 0):
@@ -105,7 +105,7 @@ class Lapack(Frame):
             print '\n\nLAPACK: cannot unzip lapack.tgz'
             print 'stderr:\n','*'*40,'\n',error,'\n','*'*40
             sys.exit()
-
+        
         comm = 'tar xf lapack.tar'
         (output, error, retz) = runShellCommand(comm)
         if(retz != 0):
@@ -116,13 +116,22 @@ class Lapack(Frame):
         print "done"
 
         # change to LAPACK dir
-        os.chdir(os.path.join(os.getcwd(),'lapack-3.2'))
+        # Old way to go: os.chdir(os.path.join(os.getcwd(),'lapack-3.2.1'))
+        comm = 'ls -1 | grep lapack- | grep -v sca'
+        (output, error, retz) = runShellCommand(comm)
+        if(retz != 0):
+		    print '\n\nLAPACK: error changing to LAPACK dir'
+		    print 'stderr:\n','*'*40,'\n','   ->  no lapack directory found','\n','*'*40
+		    sys.exit()
+        rep_name = output.replace ("\n","")
+        print 'Installing ',rep_name,'...'
+        os.chdir(os.path.join(os.getcwd(),rep_name))
 
         # compile and generate library
         self.set_etime()
         self.write_makeinc()
 
-        print 'Compiling LAPACK (this will take several minutes)...',
+        print 'Compiling ',rep_name,' (this will take several minutes)...',
         sys.stdout.flush()
         comm = self.make+' lib'
         (output, error, retz) = runShellCommand(comm)
@@ -151,8 +160,6 @@ class Lapack(Frame):
 
 
 
-
-
     def set_etime(self):
         """ Detects the FORTRAN timer """
 
@@ -165,7 +172,7 @@ class Lapack(Frame):
       EXTERNAL           ETIME_
       T1 = ETIME_( TARRAY )
       END\n""")
-        fcomm = self.mpif77+' '+self.fcflags+' -o tmpf tmpf.f'
+        fcomm = self.f90+' '+self.f90flags+' -o tmpf tmpf.f'
         (output, error, retz) = runShellCommand(fcomm)
 
         if(retz == 0):
@@ -184,7 +191,7 @@ class Lapack(Frame):
       T1 = ETIME( TARRAY )
       END\n""")
         
-        fcomm = self.mpif77+' '+self.fcflags+' -o tmpf tmpf.f'
+        fcomm = self.f90+' '+self.f90flags+' -o tmpf tmpf.f'
         (output, error, retz) = runShellCommand(fcomm)
 
         if(retz == 0):
@@ -201,7 +208,7 @@ class Lapack(Frame):
       CALL CPU_TIME( T )
       END\n""")
         
-        fcomm = self.mpif77+' '+self.fcflags+' -o tmpf tmpf.f'
+        fcomm = self.f90+' '+self.f90flags+' -o tmpf tmpf.f'
         (output, error, retz) = runShellCommand(fcomm)
 
         if(retz == 0):
@@ -220,7 +227,7 @@ class Lapack(Frame):
       T1 = ETIME( TARRAY )
       END\n""")
         
-        fcomm = self.mpif77+' '+self.fcflags+' -o tmpf tmpf.f'
+        fcomm = self.f90+' '+self.f90flags+' -o tmpf tmpf.f'
         (output, error, retz) = runShellCommand(fcomm)
 
         if(retz == 0):
@@ -242,11 +249,11 @@ class Lapack(Frame):
         writefile('make.inc',"""
 SHELL = /bin/sh
 PLAT =
-FORTRAN  = """+self.mpif77+"""
-OPTS     = """+self.fcflags+"""
+FORTRAN  = """+self.f90+"""
+OPTS     = """+self.f90flags+"""
 DRVOPTS  = $(OPTS)
 NOOPT    = """+self.noopt+"""
-LOADER   = """+self.mpif77+"""
+LOADER   = """+self.f90+"""
 LOADOPTS =
 TIMER    = """+self.etime+"""
 ARCH     = ar
