@@ -114,24 +114,33 @@ LIBS          = $(PBLIBS)
 
         if(not os.path.isfile(os.path.join(os.getcwd(),getURLName(self.scalapackurl)))):
             downloader(self.scalapackurl, self.downcmd)
-
-        comm = 'gunzip -f scalapack-1.8.0.tgz'
+        comm = 'gunzip -f scalapack.tgz'
         (output, error, retz) = runShellCommand(comm)
         if(retz != 0):
-            print '\n\nScaLAPACK: cannot unzip scalapack-1.8.0.tgz'
+            print '\n\nScaLAPACK: cannot unzip scalapack.tgz'
             print 'stderr:\n','*'*40,'\n',error,'\n','*'*40
             sys.exit()
         
 
-        comm = 'tar xf scalapack-1.8.0.tar'
+        comm = 'tar xf scalapack.tar'
         (output, error, retz) = runShellCommand(comm)
         if(retz != 0):
-            print '\n\nScaLAPACK: cannot untar scalapack-1.8.0.tar'
+            print '\n\nScaLAPACK: cannot untar scalapack.tar'
             print 'stderr:\n','*'*40,'\n',error,'\n','*'*40
             sys.exit()
-        os.remove('scalapack-1.8.0.tar')
+        os.remove('scalapack.tar')
         
-        os.chdir(os.path.join(os.getcwd(),'scalapack-1.8.0'))
+        # change to ScaLAPACK dir
+        # os.chdir(os.path.join(os.getcwd(),'scalapack-1.8.0'))
+        comm = 'ls -1 | grep scalapack'
+        (output, error, retz) = runShellCommand(comm)
+        if(retz != 0):
+		    print '\n\nScaLAPACK: error changing to ScaLAPACK dir'
+		    print 'stderr:\n','*'*40,'\n','   ->  no ScaLAPACK directory found','\n','*'*40
+		    sys.exit()
+        rep_name = output.replace ("\n","")
+        print 'Installing ',rep_name,'...'
+        os.chdir(os.path.join(os.getcwd(),rep_name))
 
         self.write_slmakeinc()
 
